from distutils.core import setup
setup(
  name = 'cantor',
  packages = ['cantor'], # this must be the same as the name above
  version = '0.1',
  description = 'See https://github.com/gioenn/cantor',
  author = 'Giovanni Quattrocchi',
  author_email = 'giovanniquattrocchi@me.com',
  url = 'https://github.com/gioenn/cantor', # use the URL to the github repo
  download_url = 'https://github.com/gioenn/cantor/archive/master.zip', # I'll explain this in a second
  keywords = ['encoding', 'set-theory'], # arbitrary keywords
  classifiers = [],
)
